Arbiter

Struct Arbiter 

pub struct Arbiter { /* private fields */ }
Serial Port Arbiter

This is a Linux-only serial port library that offers the following benefits over directly using /dev/tty:

  1. Opens the /dev/tty file with flags for non-blocking access.
  2. Sets the termios flags to use the TTY in raw mode.
  3. Prevents deadlocks caused by input buffer starvation.
  4. Prevents data garbling by implementing transaction arbitration.
  5. Gracefully handles interrupts and timeout errors.
  6. Gracefully handles connection errors and automatically reconnects.
  7. Provides a more convenient API than the raw io::Read and io::Write.

This is an “async-less” library, and it is intended to remain that way.
If you need asynchronous behavior, you can easily make it async-compatible in your own code.

Implementations

Source

impl Arbiter

pub fn new() -> Self

Creates a new arbiter which will handle a serial port connection defined by the given serial port builder.

pub fn close(&self)

Closes the serial port

pub fn is_open(&self) -> bool

Returns true if the connection is open

pub fn open(&self, path: impl AsRef<Path>) -> Result<()>

Opens the serial port.

pub fn clear_rx_buff(&self) -> Result<()>

Clear the Rx buffer of the serial port.

pub fn transmit(&self, tx_bytes: Arc<[u8]>, deadline: Instant) -> Result<()>

Transmits data to the serial port.

pub fn transmit_str( &self, str: impl AsRef<str>, deadline: Instant, ) -> Result<()>

Transmits a string to the serial port. Returns any bytes received during transmission.

pub fn receive( &self, until: Option<u8>, deadline: Option<Instant>, ) -> Result<Option<Vec<u8>>>

Receives data from the serial port

pub fn receive_string( &self, until: Option<u8>, deadline: Option<Instant>, ) -> Result<Option<String>>

Receives data from the serial port and converts to a String

pub fn set_cooloff_duration(&self, cooloff: Option<Duration>)

Change the duration of cooloff after disconnecting due to an error and before a new connection attempt is made. If set to None then another connect attepmpt is tried without any artificial delays.